Class: Aws::OSIS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OSIS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-osis/client.rb,
sig/client.rbs
Overview
An API client for OSIS. To construct a client, you need to configure a :region and :credentials.
client = Aws::OSIS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreatePipelineEndpointResponseSuccess, _CreatePipelineResponseSuccess, _DeletePipelineEndpointResponseSuccess, _DeletePipelineResponseSuccess, _DeleteResourcePolicyResponseSuccess, _GetPipelineBlueprintResponseSuccess, _GetPipelineChangeProgressResponseSuccess, _GetPipelineResponseSuccess, _GetResourcePolicyResponseSuccess, _ListPipelineBlueprintsResponseSuccess, _ListPipelineEndpointConnectionsResponseSuccess, _ListPipelineEndpointsResponseSuccess, _ListPipelinesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutResourcePolicyResponseSuccess, _RevokePipelineEndpointConnectionsResponseSuccess, _StartPipelineResponseSuccess, _StopPipelineResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdatePipelineResponseSuccess, _ValidatePipelineResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_pipeline(params = {}) ⇒ Types::CreatePipelineResponse
Creates an OpenSearch Ingestion pipeline.
-
#create_pipeline_endpoint(params = {}) ⇒ Types::CreatePipelineEndpointResponse
Creates a VPC endpoint for an OpenSearch Ingestion pipeline.
-
#delete_pipeline(params = {}) ⇒ Struct
Deletes an OpenSearch Ingestion pipeline.
-
#delete_pipeline_endpoint(params = {}) ⇒ Struct
Deletes a VPC endpoint for an OpenSearch Ingestion pipeline.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy from an OpenSearch Ingestion resource.
-
#get_pipeline(params = {}) ⇒ Types::GetPipelineResponse
Retrieves information about an OpenSearch Ingestion pipeline.
-
#get_pipeline_blueprint(params = {}) ⇒ Types::GetPipelineBlueprintResponse
Retrieves information about a specific blueprint for OpenSearch Ingestion.
-
#get_pipeline_change_progress(params = {}) ⇒ Types::GetPipelineChangeProgressResponse
Returns progress information for the current change happening on an OpenSearch Ingestion pipeline.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource-based policy attached to an OpenSearch Ingestion resource.
-
#list_pipeline_blueprints(params = {}) ⇒ Types::ListPipelineBlueprintsResponse
Retrieves a list of all available blueprints for Data Prepper.
-
#list_pipeline_endpoint_connections(params = {}) ⇒ Types::ListPipelineEndpointConnectionsResponse
Lists the pipeline endpoints connected to pipelines in your account.
-
#list_pipeline_endpoints(params = {}) ⇒ Types::ListPipelineEndpointsResponse
Lists all pipeline endpoints in your account.
-
#list_pipelines(params = {}) ⇒ Types::ListPipelinesResponse
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all resource tags associated with an OpenSearch Ingestion pipeline.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to an OpenSearch Ingestion resource.
-
#revoke_pipeline_endpoint_connections(params = {}) ⇒ Types::RevokePipelineEndpointConnectionsResponse
Revokes pipeline endpoints from specified endpoint IDs.
-
#start_pipeline(params = {}) ⇒ Types::StartPipelineResponse
Starts an OpenSearch Ingestion pipeline.
-
#stop_pipeline(params = {}) ⇒ Types::StopPipelineResponse
Stops an OpenSearch Ingestion pipeline.
-
#tag_resource(params = {}) ⇒ Struct
Tags an OpenSearch Ingestion pipeline.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an OpenSearch Ingestion pipeline.
-
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineResponse
Updates an OpenSearch Ingestion pipeline.
-
#validate_pipeline(params = {}) ⇒ Types::ValidatePipelineResponse
Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-osis/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1586 1587 1588 |
# File 'lib/aws-sdk-osis/client.rb', line 1586 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1589 1590 1591 |
# File 'lib/aws-sdk-osis/client.rb', line 1589 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'lib/aws-sdk-osis/client.rb', line 1559 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OSIS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-osis' context[:gem_version] = '1.53.0' Seahorse::Client::Request.new(handlers, context) end |
#create_pipeline(params = {}) ⇒ Types::CreatePipelineResponse
Creates an OpenSearch Ingestion pipeline. For more information, see Creating Amazon OpenSearch Ingestion pipelines.
86 |
# File 'sig/client.rbs', line 86
def create_pipeline: (
|
#create_pipeline_endpoint(params = {}) ⇒ Types::CreatePipelineEndpointResponse
Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.
130 |
# File 'sig/client.rbs', line 130
def create_pipeline_endpoint: (
|
#delete_pipeline(params = {}) ⇒ Struct
Deletes an OpenSearch Ingestion pipeline. For more information, see Deleting Amazon OpenSearch Ingestion pipelines.
143 |
# File 'sig/client.rbs', line 143
def delete_pipeline: (
|
#delete_pipeline_endpoint(params = {}) ⇒ Struct
Deletes a VPC endpoint for an OpenSearch Ingestion pipeline.
152 |
# File 'sig/client.rbs', line 152
def delete_pipeline_endpoint: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy from an OpenSearch Ingestion resource.
161 |
# File 'sig/client.rbs', line 161
def delete_resource_policy: (
|
#get_pipeline(params = {}) ⇒ Types::GetPipelineResponse
Retrieves information about an OpenSearch Ingestion pipeline.
171 |
# File 'sig/client.rbs', line 171
def get_pipeline: (
|
#get_pipeline_blueprint(params = {}) ⇒ Types::GetPipelineBlueprintResponse
Retrieves information about a specific blueprint for OpenSearch
Ingestion. Blueprints are templates for the configuration needed for a
CreatePipeline request. For more information, see Using blueprints
to create a pipeline.
182 |
# File 'sig/client.rbs', line 182
def get_pipeline_blueprint: (
|
#get_pipeline_change_progress(params = {}) ⇒ Types::GetPipelineChangeProgressResponse
Returns progress information for the current change happening on an OpenSearch Ingestion pipeline. Currently, this operation only returns information when a pipeline is being created.
For more information, see Tracking the status of pipeline creation.
193 |
# File 'sig/client.rbs', line 193
def get_pipeline_change_progress: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource-based policy attached to an OpenSearch Ingestion resource.
204 |
# File 'sig/client.rbs', line 204
def get_resource_policy: (
|
#list_pipeline_blueprints(params = {}) ⇒ Types::ListPipelineBlueprintsResponse
Retrieves a list of all available blueprints for Data Prepper. For more information, see Using blueprints to create a pipeline.
214 |
# File 'sig/client.rbs', line 214
def list_pipeline_blueprints: (
|
#list_pipeline_endpoint_connections(params = {}) ⇒ Types::ListPipelineEndpointConnectionsResponse
Lists the pipeline endpoints connected to pipelines in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
224 |
# File 'sig/client.rbs', line 224
def list_pipeline_endpoint_connections: (
|
#list_pipeline_endpoints(params = {}) ⇒ Types::ListPipelineEndpointsResponse
Lists all pipeline endpoints in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
236 |
# File 'sig/client.rbs', line 236
def list_pipeline_endpoints: (
|
#list_pipelines(params = {}) ⇒ Types::ListPipelinesResponse
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region. For more information, see Viewing Amazon OpenSearch Ingestion pipelines.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
248 |
# File 'sig/client.rbs', line 248
def list_pipelines: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all resource tags associated with an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
259 |
# File 'sig/client.rbs', line 259
def list_tags_for_resource: (
|
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to an OpenSearch Ingestion resource. Resource-based policies grant permissions to principals to perform actions on the resource.
270 |
# File 'sig/client.rbs', line 270
def put_resource_policy: (
|
#revoke_pipeline_endpoint_connections(params = {}) ⇒ Types::RevokePipelineEndpointConnectionsResponse
Revokes pipeline endpoints from specified endpoint IDs.
281 |
# File 'sig/client.rbs', line 281
def revoke_pipeline_endpoint_connections: (
|
#start_pipeline(params = {}) ⇒ Types::StartPipelineResponse
Starts an OpenSearch Ingestion pipeline. For more information, see Starting an OpenSearch Ingestion pipeline.
292 |
# File 'sig/client.rbs', line 292
def start_pipeline: (
|
#stop_pipeline(params = {}) ⇒ Types::StopPipelineResponse
Stops an OpenSearch Ingestion pipeline. For more information, see Stopping an OpenSearch Ingestion pipeline.
302 |
# File 'sig/client.rbs', line 302
def stop_pipeline: (
|
#tag_resource(params = {}) ⇒ Struct
Tags an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
311 |
# File 'sig/client.rbs', line 311
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
326 |
# File 'sig/client.rbs', line 326
def untag_resource: (
|
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineResponse
Updates an OpenSearch Ingestion pipeline. For more information, see Updating Amazon OpenSearch Ingestion pipelines.
337 |
# File 'sig/client.rbs', line 337
def update_pipeline: (
|
#validate_pipeline(params = {}) ⇒ Types::ValidatePipelineResponse
Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation. For more information, see Creating Amazon OpenSearch Ingestion pipelines.
364 |
# File 'sig/client.rbs', line 364
def validate_pipeline: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1579 1580 1581 |
# File 'lib/aws-sdk-osis/client.rb', line 1579 def waiter_names [] end |