Class: Aws::OSIS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OSIS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-osis/client.rb
Overview
An API client for OSIS. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::OSIS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_pipeline(params = {}) ⇒ Types::CreatePipelineResponse
Creates an OpenSearch Ingestion pipeline.
-
#create_pipeline_endpoint(params = {}) ⇒ Types::CreatePipelineEndpointResponse
Creates a VPC endpoint for an OpenSearch Ingestion pipeline.
-
#delete_pipeline(params = {}) ⇒ Struct
Deletes an OpenSearch Ingestion pipeline.
-
#delete_pipeline_endpoint(params = {}) ⇒ Struct
Deletes a VPC endpoint for an OpenSearch Ingestion pipeline.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy from an OpenSearch Ingestion resource.
-
#get_pipeline(params = {}) ⇒ Types::GetPipelineResponse
Retrieves information about an OpenSearch Ingestion pipeline.
-
#get_pipeline_blueprint(params = {}) ⇒ Types::GetPipelineBlueprintResponse
Retrieves information about a specific blueprint for OpenSearch Ingestion.
-
#get_pipeline_change_progress(params = {}) ⇒ Types::GetPipelineChangeProgressResponse
Returns progress information for the current change happening on an OpenSearch Ingestion pipeline.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource-based policy attached to an OpenSearch Ingestion resource.
-
#list_pipeline_blueprints(params = {}) ⇒ Types::ListPipelineBlueprintsResponse
Retrieves a list of all available blueprints for Data Prepper.
-
#list_pipeline_endpoint_connections(params = {}) ⇒ Types::ListPipelineEndpointConnectionsResponse
Lists the pipeline endpoints connected to pipelines in your account.
-
#list_pipeline_endpoints(params = {}) ⇒ Types::ListPipelineEndpointsResponse
Lists all pipeline endpoints in your account.
-
#list_pipelines(params = {}) ⇒ Types::ListPipelinesResponse
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all resource tags associated with an OpenSearch Ingestion pipeline.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to an OpenSearch Ingestion resource.
-
#revoke_pipeline_endpoint_connections(params = {}) ⇒ Types::RevokePipelineEndpointConnectionsResponse
Revokes pipeline endpoints from specified endpoint IDs.
-
#start_pipeline(params = {}) ⇒ Types::StartPipelineResponse
Starts an OpenSearch Ingestion pipeline.
-
#stop_pipeline(params = {}) ⇒ Types::StopPipelineResponse
Stops an OpenSearch Ingestion pipeline.
-
#tag_resource(params = {}) ⇒ Struct
Tags an OpenSearch Ingestion pipeline.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an OpenSearch Ingestion pipeline.
-
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineResponse
Updates an OpenSearch Ingestion pipeline.
-
#validate_pipeline(params = {}) ⇒ Types::ValidatePipelineResponse
Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-osis/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1586 1587 1588 |
# File 'lib/aws-sdk-osis/client.rb', line 1586 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1589 1590 1591 |
# File 'lib/aws-sdk-osis/client.rb', line 1589 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'lib/aws-sdk-osis/client.rb', line 1559 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OSIS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-osis' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_pipeline(params = {}) ⇒ Types::CreatePipelineResponse
Creates an OpenSearch Ingestion pipeline. For more information, see [Creating Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html
607 608 609 610 |
# File 'lib/aws-sdk-osis/client.rb', line 607 def create_pipeline(params = {}, = {}) req = build_request(:create_pipeline, params) req.send_request() end |
#create_pipeline_endpoint(params = {}) ⇒ Types::CreatePipelineEndpointResponse
Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.
652 653 654 655 |
# File 'lib/aws-sdk-osis/client.rb', line 652 def create_pipeline_endpoint(params = {}, = {}) req = build_request(:create_pipeline_endpoint, params) req.send_request() end |
#delete_pipeline(params = {}) ⇒ Struct
Deletes an OpenSearch Ingestion pipeline. For more information, see [Deleting Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/delete-pipeline.html
679 680 681 682 |
# File 'lib/aws-sdk-osis/client.rb', line 679 def delete_pipeline(params = {}, = {}) req = build_request(:delete_pipeline, params) req.send_request() end |
#delete_pipeline_endpoint(params = {}) ⇒ Struct
Deletes a VPC endpoint for an OpenSearch Ingestion pipeline.
701 702 703 704 |
# File 'lib/aws-sdk-osis/client.rb', line 701 def delete_pipeline_endpoint(params = {}, = {}) req = build_request(:delete_pipeline_endpoint, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy from an OpenSearch Ingestion resource.
724 725 726 727 |
# File 'lib/aws-sdk-osis/client.rb', line 724 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#get_pipeline(params = {}) ⇒ Types::GetPipelineResponse
Retrieves information about an OpenSearch Ingestion pipeline.
787 788 789 790 |
# File 'lib/aws-sdk-osis/client.rb', line 787 def get_pipeline(params = {}, = {}) req = build_request(:get_pipeline, params) req.send_request() end |
#get_pipeline_blueprint(params = {}) ⇒ Types::GetPipelineBlueprintResponse
Retrieves information about a specific blueprint for OpenSearch Ingestion. Blueprints are templates for the configuration needed for a ‘CreatePipeline` request. For more information, see [Using blueprints to create a pipeline].
833 834 835 836 |
# File 'lib/aws-sdk-osis/client.rb', line 833 def get_pipeline_blueprint(params = {}, = {}) req = build_request(:get_pipeline_blueprint, params) req.send_request() end |
#get_pipeline_change_progress(params = {}) ⇒ Types::GetPipelineChangeProgressResponse
Returns progress information for the current change happening on an OpenSearch Ingestion pipeline. Currently, this operation only returns information when a pipeline is being created.
For more information, see [Tracking the status of pipeline creation].
878 879 880 881 |
# File 'lib/aws-sdk-osis/client.rb', line 878 def get_pipeline_change_progress(params = {}, = {}) req = build_request(:get_pipeline_change_progress, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource-based policy attached to an OpenSearch Ingestion resource.
910 911 912 913 |
# File 'lib/aws-sdk-osis/client.rb', line 910 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_pipeline_blueprints(params = {}) ⇒ Types::ListPipelineBlueprintsResponse
Retrieves a list of all available blueprints for Data Prepper. For more information, see [Using blueprints to create a pipeline].
939 940 941 942 |
# File 'lib/aws-sdk-osis/client.rb', line 939 def list_pipeline_blueprints(params = {}, = {}) req = build_request(:list_pipeline_blueprints, params) req.send_request() end |
#list_pipeline_endpoint_connections(params = {}) ⇒ Types::ListPipelineEndpointConnectionsResponse
Lists the pipeline endpoints connected to pipelines in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
983 984 985 986 |
# File 'lib/aws-sdk-osis/client.rb', line 983 def list_pipeline_endpoint_connections(params = {}, = {}) req = build_request(:list_pipeline_endpoint_connections, params) req.send_request() end |
#list_pipeline_endpoints(params = {}) ⇒ Types::ListPipelineEndpointsResponse
Lists all pipeline endpoints in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1031 1032 1033 1034 |
# File 'lib/aws-sdk-osis/client.rb', line 1031 def list_pipeline_endpoints(params = {}, = {}) req = build_request(:list_pipeline_endpoints, params) req.send_request() end |
#list_pipelines(params = {}) ⇒ Types::ListPipelinesResponse
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region. For more information, see [Viewing Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/list-pipeline.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-osis/client.rb', line 1090 def list_pipelines(params = {}, = {}) req = build_request(:list_pipelines, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all resource tags associated with an OpenSearch Ingestion pipeline. For more information, see [Tagging Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html
1126 1127 1128 1129 |
# File 'lib/aws-sdk-osis/client.rb', line 1126 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to an OpenSearch Ingestion resource. Resource-based policies grant permissions to principals to perform actions on the resource.
1163 1164 1165 1166 |
# File 'lib/aws-sdk-osis/client.rb', line 1163 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#revoke_pipeline_endpoint_connections(params = {}) ⇒ Types::RevokePipelineEndpointConnectionsResponse
Revokes pipeline endpoints from specified endpoint IDs.
1196 1197 1198 1199 |
# File 'lib/aws-sdk-osis/client.rb', line 1196 def revoke_pipeline_endpoint_connections(params = {}, = {}) req = build_request(:revoke_pipeline_endpoint_connections, params) req.send_request() end |
#start_pipeline(params = {}) ⇒ Types::StartPipelineResponse
Starts an OpenSearch Ingestion pipeline. For more information, see [Starting an OpenSearch Ingestion pipeline].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/pipeline–stop-start.html#pipeline–start
1264 1265 1266 1267 |
# File 'lib/aws-sdk-osis/client.rb', line 1264 def start_pipeline(params = {}, = {}) req = build_request(:start_pipeline, params) req.send_request() end |
#stop_pipeline(params = {}) ⇒ Types::StopPipelineResponse
Stops an OpenSearch Ingestion pipeline. For more information, see [Stopping an OpenSearch Ingestion pipeline].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/pipeline–stop-start.html#pipeline–stop
1332 1333 1334 1335 |
# File 'lib/aws-sdk-osis/client.rb', line 1332 def stop_pipeline(params = {}, = {}) req = build_request(:stop_pipeline, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags an OpenSearch Ingestion pipeline. For more information, see [Tagging Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html
1368 1369 1370 1371 |
# File 'lib/aws-sdk-osis/client.rb', line 1368 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an OpenSearch Ingestion pipeline. For more information, see [Tagging Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html
1400 1401 1402 1403 |
# File 'lib/aws-sdk-osis/client.rb', line 1400 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineResponse
Updates an OpenSearch Ingestion pipeline. For more information, see [Updating Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/update-pipeline.html
1510 1511 1512 1513 |
# File 'lib/aws-sdk-osis/client.rb', line 1510 def update_pipeline(params = {}, = {}) req = build_request(:update_pipeline, params) req.send_request() end |
#validate_pipeline(params = {}) ⇒ Types::ValidatePipelineResponse
Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation. For more information, see [Creating Amazon OpenSearch Ingestion pipelines].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html
1550 1551 1552 1553 |
# File 'lib/aws-sdk-osis/client.rb', line 1550 def validate_pipeline(params = {}, = {}) req = build_request(:validate_pipeline, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1579 1580 1581 |
# File 'lib/aws-sdk-osis/client.rb', line 1579 def waiter_names [] end |